"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const blocks = require("../../components/blocks/blocks.qwik.cjs");
const dynamicRenderer = require("../../components/dynamic-renderer/dynamic-renderer.qwik.cjs");
const inlinedStyles = require("../../components/inlined-styles.qwik.cjs");
const deviceSizes = require("../../constants/device-sizes.qwik.cjs");
const deopt = require("../../functions/deopt.qwik.cjs");
const getClassPropName = require("../../functions/get-class-prop-name.qwik.cjs");
const getStyle = require("../../functions/get-style.qwik.cjs");
const helpers = require("./helpers.qwik.cjs");
const qwik = require("@builder.io/qwik");
const getTagName = function getTagName2(props, state, column) {
  return column.link ? props.builderLinkComponent || "a" : "div";
};
const getWidth = function getWidth2(props, state, index) {
  var _a;
  return ((_a = state.cols[index]) == null ? void 0 : _a.width) || 100 / state.cols.length;
};
const getColumnCssWidth = function getColumnCssWidth2(props, state, index) {
  const width = getWidth(props, state, index);
  const subtractWidth = state.gutterSize * (state.cols.length - 1) * (width / 100);
  return `calc(${width}% - ${subtractWidth}px)`;
};
const getTabletStyle = function getTabletStyle2(props, state, { stackedStyle, desktopStyle }) {
  return state.stackAt === "tablet" ? stackedStyle : desktopStyle;
};
const getMobileStyle = function getMobileStyle2(props, state, { stackedStyle, desktopStyle }) {
  return state.stackAt === "never" ? desktopStyle : stackedStyle;
};
const columnsCssVars = function columnsCssVars2(props, state) {
  return {
    "--flex-dir": state.flexDir,
    "--flex-dir-tablet": getTabletStyle(props, state, {
      stackedStyle: state.flexDir,
      desktopStyle: "row"
    })
  };
};
const columnCssVars = function columnCssVars2(props, state, index) {
  const gutter = index === 0 ? 0 : state.gutterSize;
  const width = getColumnCssWidth(props, state, index);
  const gutterPixels = `${gutter}px`;
  const mobileWidth = "100%";
  const mobileMarginLeft = 0;
  const marginLeftKey = "margin-left";
  const sharedStyles = {
    display: "flex",
    flexDirection: "column",
    alignItems: "stretch"
  };
  return {
    ...sharedStyles,
    width,
    [marginLeftKey]: gutterPixels,
    "--column-width-mobile": getMobileStyle(props, state, {
      stackedStyle: mobileWidth,
      desktopStyle: width
    }),
    "--column-margin-left-mobile": getMobileStyle(props, state, {
      stackedStyle: mobileMarginLeft,
      desktopStyle: gutterPixels
    }),
    "--column-width-tablet": getTabletStyle(props, state, {
      stackedStyle: mobileWidth,
      desktopStyle: width
    }),
    "--column-margin-left-tablet": getTabletStyle(props, state, {
      stackedStyle: mobileMarginLeft,
      desktopStyle: gutterPixels
    })
  };
};
const getWidthForBreakpointSize = function getWidthForBreakpointSize2(props, state, size) {
  var _a, _b;
  const breakpointSizes = deviceSizes.getSizesForBreakpoints(((_b = (_a = props.builderContext.content) == null ? void 0 : _a.meta) == null ? void 0 : _b.breakpoints) || {});
  return breakpointSizes[size].max;
};
const columnsStyles = function columnsStyles2(props, state) {
  const childColumnDiv = `.${props.builderBlock.id}-breakpoints > .builder-column`;
  return `
        @media (max-width: ${getWidthForBreakpointSize(props, state, "medium")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir-tablet);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-tablet) !important;
            margin-left: var(--column-margin-left-tablet) !important;
          }
        }

        @media (max-width: ${getWidthForBreakpointSize(props, state, "small")}px) {
          .${props.builderBlock.id}-breakpoints {
            flex-direction: var(--flex-dir);
            align-items: stretch;
          }

          ${childColumnDiv} {
            width: var(--column-width-mobile) !important;
            margin-left: var(--column-margin-left-mobile) !important;
          }
        },
      `;
};
const getAttributes = function getAttributes2(props, state, column, index) {
  return {
    ...{},
    ...column.link ? {
      href: column.link
    } : {},
    [getClassPropName.getClassPropName()]: "builder-column",
    style: getStyle.mapStyleObjToStrIfNeeded(columnCssVars(props, state, index))
  };
};
const Columns = qwik.component$((props) => {
  var _a;
  const state = qwik.useStore({
    cols: props.columns || [],
    flexDir: props.stackColumnsAt === "never" ? "row" : props.reverseColumnsWhenStacked ? "column-reverse" : "column",
    gutterSize: typeof props.space === "number" ? props.space || 0 : 20,
    stackAt: props.stackColumnsAt || "tablet"
  });
  qwik.useStylesScoped$(STYLES);
  return /* @__PURE__ */ jsxRuntime.jsxs("div", {
    class: helpers.getColumnsClass((_a = props.builderBlock) == null ? void 0 : _a.id) + " div-Columns",
    style: columnsCssVars(props, state),
    children: [
      /* @__PURE__ */ jsxRuntime.jsx(inlinedStyles.InlinedStyles, {
        id: "builderio-columns",
        styles: columnsStyles(props, state),
        nonce: props.builderContext.nonce
      }),
      (props.columns || []).map((column, index) => {
        return /* @__PURE__ */ jsxRuntime.jsx(dynamicRenderer.DynamicRenderer, {
          TagName: getTagName(props, state, column),
          actionAttributes: {},
          attributes: getAttributes(props, state, column, index),
          children: /* @__PURE__ */ jsxRuntime.jsx(blocks.Blocks, {
            path: `component.options.columns.${index}.blocks`,
            parent: props.builderBlock.id,
            styleProp: {
              flexGrow: "1"
            },
            context: props.builderContext,
            registeredComponents: props.builderComponents,
            linkComponent: props.builderLinkComponent,
            blocks: deopt.deoptSignal(column.blocks)
          })
        }, index);
      })
    ]
  });
});
const STYLES = `
.div-Columns {
  display: flex;
  line-height: normal;
}
`;
exports.Columns = Columns;
exports.STYLES = STYLES;
exports.columnCssVars = columnCssVars;
exports.columnsCssVars = columnsCssVars;
exports.columnsStyles = columnsStyles;
exports.default = Columns;
exports.getAttributes = getAttributes;
exports.getColumnCssWidth = getColumnCssWidth;
exports.getMobileStyle = getMobileStyle;
exports.getTabletStyle = getTabletStyle;
exports.getTagName = getTagName;
exports.getWidth = getWidth;
exports.getWidthForBreakpointSize = getWidthForBreakpointSize;
