"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const target = require("../../constants/target.qwik.cjs");
const getBlockComponentOptions = require("../../functions/get-block-component-options.qwik.cjs");
const getProcessedBlock = require("../../functions/get-processed-block.qwik.cjs");
const animator = require("./animator.qwik.cjs");
const block_helpers = require("./block.helpers.qwik.cjs");
const blockStyles = require("./components/block-styles.qwik.cjs");
const blockWrapper = require("./components/block-wrapper.qwik.cjs");
const componentRef = require("./components/component-ref/component-ref.qwik.cjs");
const repeatedBlock = require("./components/repeated-block.qwik.cjs");
const qwik = require("@builder.io/qwik");
const Block = qwik.component$((props) => {
  var _a;
  qwik.useStore({
    _processedBlock: {
      value: null,
      update: false
    }
  });
  const repeatItem = qwik.useComputed$(() => {
    return block_helpers.getRepeatItemData({
      block: props.block,
      context: props.context
    });
  });
  const processedBlock = qwik.useComputed$(() => {
    var _a2;
    const blockToUse = ((_a2 = props.block.repeat) == null ? void 0 : _a2.collection) ? props.block : getProcessedBlock.getProcessedBlock({
      block: props.block,
      localState: props.context.localState,
      rootState: props.context.rootState,
      rootSetState: props.context.rootSetState,
      context: props.context.context,
      shouldEvaluateBindings: true
    });
    return blockToUse;
  });
  const blockComponent = qwik.useComputed$(() => {
    return block_helpers.getComponent({
      block: processedBlock.value,
      registeredComponents: props.registeredComponents
    });
  });
  const Tag = qwik.useComputed$(() => {
    var _a2;
    const shouldUseLink = props.block.tagName === "a" || ((_a2 = processedBlock.value.properties) == null ? void 0 : _a2.href) || processedBlock.value.href;
    if (shouldUseLink) {
      return props.linkComponent || "a";
    }
    return props.block.tagName || "div";
  });
  const canShowBlock = qwik.useComputed$(() => {
    var _a2, _b;
    if ((_a2 = props.block.repeat) == null ? void 0 : _a2.collection) {
      if ((_b = repeatItem.value) == null ? void 0 : _b.length)
        return true;
      return false;
    }
    const shouldHide = "hide" in processedBlock.value ? processedBlock.value.hide : false;
    const shouldShow = "show" in processedBlock.value ? processedBlock.value.show : true;
    return shouldShow && !shouldHide;
  });
  const childrenWithoutParentComponent = qwik.useComputed$(() => {
    var _a2;
    const shouldRenderChildrenOutsideRef = !((_a2 = blockComponent.value) == null ? void 0 : _a2.component) && !repeatItem.value;
    return shouldRenderChildrenOutsideRef ? processedBlock.value.children ?? [] : [];
  });
  const componentRefProps = qwik.useComputed$(() => {
    var _a2, _b, _c;
    return {
      blockChildren: processedBlock.value.children ?? [],
      componentRef: (_a2 = blockComponent.value) == null ? void 0 : _a2.component,
      componentOptions: {
        ...getBlockComponentOptions.getBlockComponentOptions(processedBlock.value),
        ...block_helpers.provideBuilderBlock(blockComponent.value, processedBlock.value),
        ...block_helpers.provideBuilderContext(blockComponent.value, props.context),
        ...block_helpers.provideLinkComponent(blockComponent.value, props.linkComponent),
        ...block_helpers.provideRegisteredComponents(blockComponent.value, props.registeredComponents)
      },
      context: props.context,
      linkComponent: props.linkComponent,
      registeredComponents: props.registeredComponents,
      builderBlock: processedBlock.value,
      includeBlockProps: ((_b = blockComponent.value) == null ? void 0 : _b.noWrap) === true,
      isInteractive: !(((_c = blockComponent.value) == null ? void 0 : _c.isRSC) && target.TARGET === "rsc")
    };
  });
  qwik.useVisibleTask$(() => {
    const blockId = processedBlock.value.id;
    const animations = processedBlock.value.animations;
    if (animations && blockId) {
      animator.bindAnimations(animations.map((animation) => ({
        ...animation,
        elementId: blockId
      })));
    }
  });
  qwik.useTask$(({ track }) => {
  });
  return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, {
    children: canShowBlock.value ? /* @__PURE__ */ jsxRuntime.jsxs(jsxRuntime.Fragment, {
      children: [
        /* @__PURE__ */ jsxRuntime.jsx(blockStyles.BlockStyles, {
          block: processedBlock.value,
          context: props.context
        }),
        !((_a = blockComponent.value) == null ? void 0 : _a.noWrap) ? !repeatItem.value ? /* @__PURE__ */ jsxRuntime.jsxs(blockWrapper.BlockWrapper, {
          Wrapper: Tag.value,
          block: processedBlock.value,
          context: props.context,
          children: [
            /* @__PURE__ */ jsxRuntime.jsx(componentRef.ComponentRef, {
              componentRef: componentRefProps.value.componentRef,
              componentOptions: componentRefProps.value.componentOptions,
              blockChildren: componentRefProps.value.blockChildren,
              context: componentRefProps.value.context,
              registeredComponents: componentRefProps.value.registeredComponents,
              linkComponent: componentRefProps.value.linkComponent,
              builderBlock: componentRefProps.value.builderBlock,
              includeBlockProps: componentRefProps.value.includeBlockProps,
              isInteractive: componentRefProps.value.isInteractive
            }),
            (childrenWithoutParentComponent.value || []).map((child) => {
              return /* @__PURE__ */ jsxRuntime.jsx(Block, {
                block: child,
                registeredComponents: props.registeredComponents,
                linkComponent: props.linkComponent,
                context: props.context
              }, child.id);
            })
          ]
        }) : (repeatItem.value || []).map((data, index) => {
          return /* @__PURE__ */ jsxRuntime.jsx(repeatedBlock.RepeatedBlock, {
            repeatContext: data.context,
            block: data.block,
            registeredComponents: props.registeredComponents,
            linkComponent: props.linkComponent
          }, index);
        }) : !repeatItem.value ? /* @__PURE__ */ jsxRuntime.jsx(componentRef.ComponentRef, {
          componentRef: componentRefProps.value.componentRef,
          componentOptions: componentRefProps.value.componentOptions,
          blockChildren: componentRefProps.value.blockChildren,
          context: componentRefProps.value.context,
          registeredComponents: componentRefProps.value.registeredComponents,
          linkComponent: componentRefProps.value.linkComponent,
          builderBlock: componentRefProps.value.builderBlock,
          includeBlockProps: componentRefProps.value.includeBlockProps,
          isInteractive: componentRefProps.value.isInteractive
        }) : (repeatItem.value || []).map((data, index) => {
          return /* @__PURE__ */ jsxRuntime.jsx(repeatedBlock.RepeatedBlock, {
            repeatContext: data.context,
            block: data.block,
            registeredComponents: props.registeredComponents,
            linkComponent: props.linkComponent
          }, index);
        })
      ]
    }) : null
  });
});
const Block$1 = Block;
exports.Block = Block;
exports.default = Block$1;
