import { jsx, Fragment, jsxs } from "@builder.io/qwik/jsx-runtime";
import { TARGET } from "../../constants/target.qwik.mjs";
import { getBlockComponentOptions } from "../../functions/get-block-component-options.qwik.mjs";
import { getProcessedBlock } from "../../functions/get-processed-block.qwik.mjs";
import { bindAnimations } from "./animator.qwik.mjs";
import { getRepeatItemData, getComponent, provideBuilderBlock, provideBuilderContext, provideLinkComponent, provideRegisteredComponents } from "./block.helpers.qwik.mjs";
import { BlockStyles } from "./components/block-styles.qwik.mjs";
import { BlockWrapper } from "./components/block-wrapper.qwik.mjs";
import { ComponentRef } from "./components/component-ref/component-ref.qwik.mjs";
import { RepeatedBlock } from "./components/repeated-block.qwik.mjs";
import { component$, useStore, useComputed$, useVisibleTask$, useTask$ } from "@builder.io/qwik";
const Block = component$((props) => {
  var _a;
  useStore({
    _processedBlock: {
      value: null,
      update: false
    }
  });
  const repeatItem = useComputed$(() => {
    return getRepeatItemData({
      block: props.block,
      context: props.context
    });
  });
  const processedBlock = useComputed$(() => {
    var _a2;
    const blockToUse = ((_a2 = props.block.repeat) == null ? void 0 : _a2.collection) ? props.block : getProcessedBlock({
      block: props.block,
      localState: props.context.localState,
      rootState: props.context.rootState,
      rootSetState: props.context.rootSetState,
      context: props.context.context,
      shouldEvaluateBindings: true
    });
    return blockToUse;
  });
  const blockComponent = useComputed$(() => {
    return getComponent({
      block: processedBlock.value,
      registeredComponents: props.registeredComponents
    });
  });
  const Tag = useComputed$(() => {
    var _a2;
    const shouldUseLink = props.block.tagName === "a" || ((_a2 = processedBlock.value.properties) == null ? void 0 : _a2.href) || processedBlock.value.href;
    if (shouldUseLink) {
      return props.linkComponent || "a";
    }
    return props.block.tagName || "div";
  });
  const canShowBlock = useComputed$(() => {
    var _a2, _b;
    if ((_a2 = props.block.repeat) == null ? void 0 : _a2.collection) {
      if ((_b = repeatItem.value) == null ? void 0 : _b.length)
        return true;
      return false;
    }
    const shouldHide = "hide" in processedBlock.value ? processedBlock.value.hide : false;
    const shouldShow = "show" in processedBlock.value ? processedBlock.value.show : true;
    return shouldShow && !shouldHide;
  });
  const childrenWithoutParentComponent = useComputed$(() => {
    var _a2;
    const shouldRenderChildrenOutsideRef = !((_a2 = blockComponent.value) == null ? void 0 : _a2.component) && !repeatItem.value;
    return shouldRenderChildrenOutsideRef ? processedBlock.value.children ?? [] : [];
  });
  const componentRefProps = useComputed$(() => {
    var _a2, _b, _c;
    return {
      blockChildren: processedBlock.value.children ?? [],
      componentRef: (_a2 = blockComponent.value) == null ? void 0 : _a2.component,
      componentOptions: {
        ...getBlockComponentOptions(processedBlock.value),
        ...provideBuilderBlock(blockComponent.value, processedBlock.value),
        ...provideBuilderContext(blockComponent.value, props.context),
        ...provideLinkComponent(blockComponent.value, props.linkComponent),
        ...provideRegisteredComponents(blockComponent.value, props.registeredComponents)
      },
      context: props.context,
      linkComponent: props.linkComponent,
      registeredComponents: props.registeredComponents,
      builderBlock: processedBlock.value,
      includeBlockProps: ((_b = blockComponent.value) == null ? void 0 : _b.noWrap) === true,
      isInteractive: !(((_c = blockComponent.value) == null ? void 0 : _c.isRSC) && TARGET === "rsc")
    };
  });
  useVisibleTask$(() => {
    const blockId = processedBlock.value.id;
    const animations = processedBlock.value.animations;
    if (animations && blockId) {
      bindAnimations(animations.map((animation) => ({
        ...animation,
        elementId: blockId
      })));
    }
  });
  useTask$(({ track }) => {
  });
  return /* @__PURE__ */ jsx(Fragment, {
    children: canShowBlock.value ? /* @__PURE__ */ jsxs(Fragment, {
      children: [
        /* @__PURE__ */ jsx(BlockStyles, {
          block: processedBlock.value,
          context: props.context
        }),
        !((_a = blockComponent.value) == null ? void 0 : _a.noWrap) ? !repeatItem.value ? /* @__PURE__ */ jsxs(BlockWrapper, {
          Wrapper: Tag.value,
          block: processedBlock.value,
          context: props.context,
          children: [
            /* @__PURE__ */ jsx(ComponentRef, {
              componentRef: componentRefProps.value.componentRef,
              componentOptions: componentRefProps.value.componentOptions,
              blockChildren: componentRefProps.value.blockChildren,
              context: componentRefProps.value.context,
              registeredComponents: componentRefProps.value.registeredComponents,
              linkComponent: componentRefProps.value.linkComponent,
              builderBlock: componentRefProps.value.builderBlock,
              includeBlockProps: componentRefProps.value.includeBlockProps,
              isInteractive: componentRefProps.value.isInteractive
            }),
            (childrenWithoutParentComponent.value || []).map((child) => {
              return /* @__PURE__ */ jsx(Block, {
                block: child,
                registeredComponents: props.registeredComponents,
                linkComponent: props.linkComponent,
                context: props.context
              }, child.id);
            })
          ]
        }) : (repeatItem.value || []).map((data, index) => {
          return /* @__PURE__ */ jsx(RepeatedBlock, {
            repeatContext: data.context,
            block: data.block,
            registeredComponents: props.registeredComponents,
            linkComponent: props.linkComponent
          }, index);
        }) : !repeatItem.value ? /* @__PURE__ */ jsx(ComponentRef, {
          componentRef: componentRefProps.value.componentRef,
          componentOptions: componentRefProps.value.componentOptions,
          blockChildren: componentRefProps.value.blockChildren,
          context: componentRefProps.value.context,
          registeredComponents: componentRefProps.value.registeredComponents,
          linkComponent: componentRefProps.value.linkComponent,
          builderBlock: componentRefProps.value.builderBlock,
          includeBlockProps: componentRefProps.value.includeBlockProps,
          isInteractive: componentRefProps.value.isInteractive
        }) : (repeatItem.value || []).map((data, index) => {
          return /* @__PURE__ */ jsx(RepeatedBlock, {
            repeatContext: data.context,
            block: data.block,
            registeredComponents: props.registeredComponents,
            linkComponent: props.linkComponent
          }, index);
        })
      ]
    }) : null
  });
});
const Block$1 = Block;
export {
  Block,
  Block$1 as default
};
