"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const getCssFromFont = (font) => {
  var _a;
  const family = font.family + (font.kind && !font.kind.includes("#") ? ", " + font.kind : "");
  const name = family.split(",")[0];
  const url = font.fileUrl ?? ((_a = font == null ? void 0 : font.files) == null ? void 0 : _a.regular);
  let str = "";
  if (url && family && name) {
    str += `
@font-face {
font-family: "${family}";
src: local("${name}"), url('${url}') format('woff2');
font-display: fallback;
font-weight: 400;
}
      `.trim();
  }
  if (font.files) {
    for (const weight in font.files) {
      const isNumber = String(Number(weight)) === weight;
      if (!isNumber) {
        continue;
      }
      const weightUrl = font.files[weight];
      if (weightUrl && weightUrl !== url) {
        str += `
@font-face {
font-family: "${family}";
src: url('${weightUrl}') format('woff2');
font-display: fallback;
font-weight: ${weight};
}
        `.trim();
      }
    }
  }
  return str;
};
const getFontCss = ({ customFonts }) => {
  var _a;
  return ((_a = customFonts == null ? void 0 : customFonts.map((font) => getCssFromFont(font))) == null ? void 0 : _a.join(" ")) || "";
};
const getCss = ({ cssCode, contentId }) => {
  if (!cssCode) {
    return "";
  }
  if (!contentId) {
    return cssCode;
  }
  return (cssCode == null ? void 0 : cssCode.replace(/&/g, `div[builder-content-id="${contentId}"]`)) || "";
};
const DEFAULT_STYLES = `
.builder-button {
  all: unset;
}

.builder-text > p:first-of-type, .builder-text > .builder-paragraph:first-of-type {
  margin: 0;
}
.builder-text > p, .builder-text > .builder-paragraph {
  color: inherit;
  line-height: inherit;
  letter-spacing: inherit;
  font-weight: inherit;
  font-size: inherit;
  text-align: inherit;
  font-family: inherit;
}
`;
const getDefaultStyles = (isNested) => {
  return !isNested ? DEFAULT_STYLES : "";
};
const getWrapperClassName = (variationId) => {
  return `variant-${variationId}`;
};
exports.getCss = getCss;
exports.getDefaultStyles = getDefaultStyles;
exports.getFontCss = getFontCss;
exports.getWrapperClassName = getWrapperClassName;
