"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const isBrowser = require("../is-browser.qwik.cjs");
const isEditing = require("../is-editing.qwik.cjs");
const helpers = require("../track/helpers.qwik.cjs");
const getFunctionArguments = ({ builder, context, event, state }) => {
  return Object.entries({
    state,
    Builder: builder,
    // legacy
    builder,
    context,
    event
  });
};
const getBuilderGlobals = () => ({
  isEditing: isEditing.isEditing(),
  isBrowser: isBrowser.isBrowser(),
  isServer: !isBrowser.isBrowser(),
  getUserAttributes: () => helpers.getUserAttributes()
});
const parseCode = (code, { isExpression = true }) => {
  const useReturn = (
    // we disable this for cases where we definitely don't want a return
    isExpression && !(code.includes(";") || code.includes(" return ") || code.trim().startsWith("return "))
  );
  const useCode = useReturn ? `return (${code});` : code;
  return useCode;
};
function flattenState({ rootState, localState, rootSetState }) {
  return new Proxy(rootState, {
    get: (target, prop) => {
      if (localState && prop in localState) {
        return localState[prop];
      }
      const val = target[prop];
      if (typeof val === "object" && val !== null) {
        return flattenState({
          rootState: val,
          localState: void 0,
          rootSetState: rootSetState ? (subState) => {
            target[prop] = subState;
            rootSetState(target);
          } : void 0
        });
      }
      return val;
    },
    set: (target, prop, value) => {
      if (localState && prop in localState) {
        throw new Error("Writing to local state is not allowed as it is read-only.");
      }
      target[prop] = value;
      rootSetState == null ? void 0 : rootSetState(target);
      return true;
    }
  });
}
exports.flattenState = flattenState;
exports.getBuilderGlobals = getBuilderGlobals;
exports.getFunctionArguments = getFunctionArguments;
exports.parseCode = parseCode;
