"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const target = require("../../constants/target.qwik.cjs");
const logger = require("../../helpers/logger.qwik.cjs");
const sdkHeaders = require("../../helpers/sdk-headers.qwik.cjs");
const sessionId = require("../../helpers/sessionId.qwik.cjs");
const visitorId = require("../../helpers/visitorId.qwik.cjs");
const isBrowser = require("../is-browser.qwik.cjs");
const isEditing = require("../is-editing.qwik.cjs");
const helpers = require("./helpers.qwik.cjs");
const getTrackingEventData = async ({ canTrack }) => {
  if (!canTrack) {
    return {
      visitorId: void 0,
      sessionId: void 0
    };
  }
  const sessionId$1 = await sessionId.getSessionId({
    canTrack
  });
  const visitorId$1 = visitorId.getVisitorId({
    canTrack
  });
  return {
    sessionId: sessionId$1,
    visitorId: visitorId$1
  };
};
const createEvent = async ({ type: eventType, canTrack, apiKey, metadata, ...properties }) => ({
  type: eventType,
  data: {
    ...properties,
    metadata: {
      url: location.href,
      ...metadata
    },
    ...await getTrackingEventData({
      canTrack
    }),
    userAttributes: helpers.getUserAttributes(),
    ownerId: apiKey
  }
});
async function _track(eventProps) {
  if (!eventProps.apiKey) {
    logger.logger.error("Missing API key for track call. Please provide your API key.");
    return;
  }
  if (!eventProps.canTrack) {
    return;
  }
  if (isEditing.isEditing()) {
    return;
  }
  if (!(isBrowser.isBrowser() || target.TARGET === "reactNative")) {
    return;
  }
  return fetch(`https://cdn.builder.io/api/v1/track`, {
    method: "POST",
    body: JSON.stringify({
      events: [
        await createEvent(eventProps)
      ]
    }),
    headers: {
      "content-type": "application/json",
      ...sdkHeaders.getSdkHeaders()
    },
    mode: "cors"
  }).catch((err) => {
    console.error("Failed to track: ", err);
  });
}
const track = (args) => _track({
  ...args,
  canTrack: true
});
exports._track = _track;
exports.track = track;
