import { jsxs, jsx } from "@builder.io/qwik/jsx-runtime";
import Block from "../../../components/block/block.qwik.mjs";
import { Blocks } from "../../../components/blocks/blocks.qwik.mjs";
import { getEnv } from "../../../functions/get-env.qwik.mjs";
import { get } from "../../../functions/get.qwik.mjs";
import { isEditing } from "../../../functions/is-editing.qwik.mjs";
import { set } from "../../../functions/set.qwik.mjs";
import { component$, useStylesScoped$, useSignal, useStore, $ } from "@builder.io/qwik";
const mergeNewRootState = function mergeNewRootState2(props, state, formRef, newData) {
  var _a, _b;
  const combinedState = {
    ...props.builderContext.rootState,
    ...newData
  };
  if (props.builderContext.rootSetState) {
    (_b = (_a = props.builderContext).rootSetState) == null ? void 0 : _b.call(_a, combinedState);
  } else {
    props.builderContext.rootState = combinedState;
  }
};
const submissionState = function submissionState2(props, state, formRef) {
  return isEditing() && props.previewState || state.formState;
};
const onSubmit = function onSubmit2(props, state, formRef, event) {
  var _a;
  const sendWithJsProp = props.sendWithJs || props.sendSubmissionsTo === "email";
  if (props.sendSubmissionsTo === "zapier") {
    event.preventDefault();
  } else if (sendWithJsProp) {
    if (!(props.action || props.sendSubmissionsTo === "email")) {
      event.preventDefault();
      return;
    }
    event.preventDefault();
    const el = event.currentTarget || event.target;
    const headers = props.customHeaders || {};
    let body;
    const formData = new FormData(el);
    const formPairs = Array.from(el.querySelectorAll("input,select,textarea")).filter((el2) => !!el2.name).map((el2) => {
      let value;
      const key = el2.name;
      if (el2 instanceof HTMLInputElement) {
        if (el2.type === "radio") {
          if (el2.checked) {
            value = el2.name;
            return {
              key,
              value
            };
          }
        } else if (el2.type === "checkbox") {
          value = el2.checked;
        } else if (el2.type === "number" || el2.type === "range") {
          const num = el2.valueAsNumber;
          if (!isNaN(num)) {
            value = num;
          }
        } else if (el2.type === "file") {
          value = el2.files;
        } else {
          value = el2.value;
        }
      } else {
        value = el2.value;
      }
      return {
        key,
        value
      };
    });
    let formContentType = props.contentType;
    if (props.sendSubmissionsTo === "email") {
      formContentType = "multipart/form-data";
    }
    Array.from(formPairs).forEach(({ value }) => {
      if (value instanceof File || Array.isArray(value) && value[0] instanceof File || value instanceof FileList) {
        formContentType = "multipart/form-data";
      }
    });
    if (formContentType !== "application/json") {
      body = formData;
    } else {
      const json = {};
      Array.from(formPairs).forEach(({ value, key }) => {
        set(json, key, value);
      });
      body = JSON.stringify(json);
    }
    if (formContentType && formContentType !== "multipart/form-data") {
      if (
        /* Zapier doesn't allow content-type header to be sent from browsers */
        !(sendWithJsProp && ((_a = props.action) == null ? void 0 : _a.includes("zapier.com")))
      ) {
        headers["content-type"] = formContentType;
      }
    }
    const presubmitEvent = new CustomEvent("presubmit", {
      detail: {
        body
      }
    });
    if (formRef.value) {
      formRef.value.dispatchEvent(presubmitEvent);
      if (presubmitEvent.defaultPrevented) {
        return;
      }
    }
    state.formState = "sending";
    const formUrl = `${getEnv() === "dev" ? "http://localhost:5000" : "https://builder.io"}/api/v1/form-submit?apiKey=${props.builderContext.apiKey}&to=${btoa(props.sendSubmissionsToEmail || "")}&name=${encodeURIComponent(props.name || "")}`;
    fetch(props.sendSubmissionsTo === "email" ? formUrl : props.action, {
      body,
      headers,
      method: props.method || "post"
    }).then(async (res) => {
      let body2;
      const contentType = res.headers.get("content-type");
      if (contentType && contentType.indexOf("application/json") !== -1) {
        body2 = await res.json();
      } else {
        body2 = await res.text();
      }
      if (!res.ok && props.errorMessagePath) {
        let message = get(body2, props.errorMessagePath);
        if (message) {
          if (typeof message !== "string") {
            message = JSON.stringify(message);
          }
          state.formErrorMessage = message;
          mergeNewRootState(props, state, formRef, {
            formErrorMessage: message
          });
        }
      }
      state.responseData = body2;
      state.formState = res.ok ? "success" : "error";
      if (res.ok) {
        const submitSuccessEvent = new CustomEvent("submit:success", {
          detail: {
            res,
            body: body2
          }
        });
        if (formRef.value) {
          formRef.value.dispatchEvent(submitSuccessEvent);
          if (submitSuccessEvent.defaultPrevented) {
            return;
          }
          if (props.resetFormOnSubmit !== false) {
            formRef.value.reset();
          }
        }
        if (props.successUrl) {
          if (formRef.value) {
            const event2 = new CustomEvent("route", {
              detail: {
                url: props.successUrl
              }
            });
            formRef.value.dispatchEvent(event2);
            if (!event2.defaultPrevented) {
              location.href = props.successUrl;
            }
          } else {
            location.href = props.successUrl;
          }
        }
      }
    }, (err) => {
      const submitErrorEvent = new CustomEvent("submit:error", {
        detail: {
          error: err
        }
      });
      if (formRef.value) {
        formRef.value.dispatchEvent(submitErrorEvent);
        if (submitErrorEvent.defaultPrevented) {
          return;
        }
      }
      state.responseData = err;
      state.formState = "error";
    });
  }
};
const FormComponent = component$((props) => {
  var _a;
  useStylesScoped$(STYLES);
  const formRef = useSignal();
  const state = useStore({
    formErrorMessage: "",
    formState: "unsubmitted",
    responseData: null
  });
  return /* @__PURE__ */ jsxs("form", {
    validate: props.validate,
    ref: formRef,
    action: (() => {
      !props.sendWithJs && props.action;
    })(),
    method: props.method,
    name: props.name,
    onSubmit$: $((event) => onSubmit(props, state, formRef, event)),
    "preventdefault:submit": true,
    ...props.attributes,
    children: [
      props.builderBlock && props.builderBlock.children ? (((_a = props.builderBlock) == null ? void 0 : _a.children) || []).map((block, idx) => {
        return /* @__PURE__ */ jsx(Block, {
          block,
          context: props.builderContext,
          registeredComponents: props.builderComponents,
          linkComponent: props.builderLinkComponent
        }, `form-block-${idx}`);
      }) : null,
      submissionState(props, state) === "error" ? /* @__PURE__ */ jsx(Blocks, {
        path: "errorMessage",
        blocks: props.errorMessage,
        context: props.builderContext
      }) : null,
      submissionState(props, state) === "sending" ? /* @__PURE__ */ jsx(Blocks, {
        path: "sendingMessage",
        blocks: props.sendingMessage,
        context: props.builderContext
      }) : null,
      submissionState(props, state) === "error" && state.responseData ? /* @__PURE__ */ jsx("pre", {
        class: "builder-form-error-text pre-FormComponent",
        children: JSON.stringify(state.responseData, null, 2)
      }) : null,
      submissionState(props, state) === "success" ? /* @__PURE__ */ jsx(Blocks, {
        path: "successMessage",
        blocks: props.successMessage,
        context: props.builderContext
      }) : null
    ]
  });
});
const STYLES = `
.pre-FormComponent {
  padding: 10px;
  color: red;
  text-align: center;
}
`;
export {
  FormComponent,
  STYLES,
  FormComponent as default,
  mergeNewRootState,
  onSubmit,
  submissionState
};
