"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const deviceSizes = require("../../../constants/device-sizes.qwik.cjs");
const camelToKebabCase = require("../../../functions/camel-to-kebab-case.qwik.cjs");
const css = require("../../../helpers/css.qwik.cjs");
const nullable = require("../../../helpers/nullable.qwik.cjs");
const inlinedStyles = require("../../inlined-styles.qwik.cjs");
const qwik = require("@builder.io/qwik");
const BlockStyles = qwik.component$((props) => {
  const canShowBlock = qwik.useComputed$(() => {
    const processedBlock = props.block;
    if (nullable.checkIsDefined(processedBlock.hide)) {
      return !processedBlock.hide;
    }
    if (nullable.checkIsDefined(processedBlock.show)) {
      return processedBlock.show;
    }
    return true;
  });
  const css$1 = qwik.useComputed$(() => {
    var _a, _b, _c;
    const processedBlock = props.block;
    const styles = processedBlock.responsiveStyles;
    const content = props.context.content;
    const sizesWithUpdatedBreakpoints = deviceSizes.getSizesForBreakpoints(((_a = content == null ? void 0 : content.meta) == null ? void 0 : _a.breakpoints) || {});
    const largeStyles = styles == null ? void 0 : styles.large;
    const mediumStyles = styles == null ? void 0 : styles.medium;
    const smallStyles = styles == null ? void 0 : styles.small;
    const className = processedBlock.id;
    if (!className) {
      return "";
    }
    const largeStylesClass = largeStyles ? css.createCssClass({
      className,
      styles: largeStyles
    }) : "";
    const mediumStylesClass = mediumStyles ? css.createCssClass({
      className,
      styles: mediumStyles,
      mediaQuery: deviceSizes.getMaxWidthQueryForSize("medium", sizesWithUpdatedBreakpoints)
    }) : "";
    const smallStylesClass = smallStyles ? css.createCssClass({
      className,
      styles: smallStyles,
      mediaQuery: deviceSizes.getMaxWidthQueryForSize("small", sizesWithUpdatedBreakpoints)
    }) : "";
    const hoverAnimation = processedBlock.animations && processedBlock.animations.find((item) => item.trigger === "hover");
    let hoverStylesClass = "";
    if (hoverAnimation) {
      const hoverStyles = ((_c = (_b = hoverAnimation.steps) == null ? void 0 : _b[1]) == null ? void 0 : _c.styles) || {};
      hoverStylesClass = css.createCssClass({
        className: `${className}:hover`,
        styles: {
          ...hoverStyles,
          transition: `all ${hoverAnimation.duration}s ${camelToKebabCase.camelToKebabCase(hoverAnimation.easing)}`,
          transitionDelay: hoverAnimation.delay ? `${hoverAnimation.delay}s` : "0s"
        }
      }) || "";
    }
    return [
      largeStylesClass,
      mediumStylesClass,
      smallStylesClass,
      hoverStylesClass
    ].join(" ");
  });
  return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, {
    children: css$1.value && canShowBlock.value ? /* @__PURE__ */ jsxRuntime.jsx(inlinedStyles.InlinedStyles, {
      id: "builderio-block",
      styles: css$1.value,
      nonce: props.context.nonce
    }) : null
  });
});
exports.BlockStyles = BlockStyles;
exports.default = BlockStyles;
