import { jsxs, jsx } from "@builder.io/qwik/jsx-runtime";
import { getDefaultRegisteredComponents } from "../../constants/builder-registered-components.qwik.mjs";
import ComponentsContext from "../../context/components.context.qwik.mjs";
import { evaluate } from "../../functions/evaluate/evaluate.qwik.mjs";
import { serializeIncludingFunctions } from "../../functions/register-component.qwik.mjs";
import { logger } from "../../helpers/logger.qwik.mjs";
import { Blocks } from "../blocks/blocks.qwik.mjs";
import { getUpdateVariantVisibilityScript } from "../content-variants/helpers.qwik.mjs";
import { InlinedScript } from "../inlined-script.qwik.mjs";
import { EnableEditor } from "./components/enable-editor.qwik.mjs";
import { ContentStyles } from "./components/styles.qwik.mjs";
import { getContentInitialValue, getRootStateInitialValue } from "./content.helpers.qwik.mjs";
import { component$, useStore, useContextProvider, useTask$ } from "@builder.io/qwik";
const ContentComponent = component$((props) => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k;
  const state = useStore({
    builderContextSignal: {
      content: getContentInitialValue({
        content: JSON.parse(JSON.stringify(props.content || {})),
        data: props.data
      }),
      localState: void 0,
      rootState: getRootStateInitialValue({
        content: props.content,
        data: props.data,
        locale: props.locale
      }),
      rootSetState: void 0,
      context: props.context || {},
      canTrack: props.canTrack,
      apiKey: props.apiKey,
      apiVersion: props.apiVersion,
      componentInfos: [
        ...getDefaultRegisteredComponents(),
        ...((_a = props.customComponents) == null ? void 0 : _a.filter(({ models }) => {
          if (!(models == null ? void 0 : models.length))
            return true;
          if (!props.model)
            return true;
          return models.includes(props.model);
        })) || []
      ].reduce((acc, { component: _, ...info }) => ({
        ...acc,
        [info.name]: serializeIncludingFunctions(info)
      }), {}),
      inheritedStyles: {},
      BlocksWrapper: props.blocksWrapper || "div",
      BlocksWrapperProps: props.blocksWrapperProps || {},
      nonce: props.nonce || ""
    },
    registeredComponents: [
      ...getDefaultRegisteredComponents(),
      ...((_b = props.customComponents) == null ? void 0 : _b.filter(({ models }) => {
        if (!(models == null ? void 0 : models.length))
          return true;
        if (!props.model)
          return true;
        return models.includes(props.model);
      })) || []
    ].reduce((acc, { component, ...info }) => ({
      ...acc,
      [info.name]: {
        component,
        ...serializeIncludingFunctions(info)
      }
    }), {}),
    scriptStr: getUpdateVariantVisibilityScript({
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      variationId: (_c = props.content) == null ? void 0 : _c.testVariationId,
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
      contentId: (_d = props.content) == null ? void 0 : _d.id
    })
  }, {
    deep: true
  });
  useContextProvider(ComponentsContext, useStore({
    registeredComponents: state.registeredComponents
  }));
  useTask$(() => {
    var _a2, _b2;
    if (!props.apiKey) {
      logger.error("No API key provided to `Content` component. This can cause issues. Please provide an API key using the `apiKey` prop.");
    }
    const jsCode = (_b2 = (_a2 = state.builderContextSignal.content) == null ? void 0 : _a2.data) == null ? void 0 : _b2.jsCode;
    if (jsCode) {
      evaluate({
        code: jsCode,
        context: props.context || {},
        localState: void 0,
        rootState: state.builderContextSignal.rootState,
        rootSetState: (newState) => {
          var _a3, _b3;
          (_b3 = (_a3 = state.builderContextSignal).rootSetState) == null ? void 0 : _b3.call(_a3, newState);
        },
        isExpression: false
      });
    }
  });
  return /* @__PURE__ */ jsxs(EnableEditor, {
    nonce: props.nonce,
    content: props.content,
    data: props.data,
    model: props.model,
    context: props.context,
    apiKey: props.apiKey,
    canTrack: props.canTrack,
    locale: props.locale,
    enrich: props.enrich,
    showContent: props.showContent,
    builderContextSignal: state.builderContextSignal,
    contentWrapper: props.contentWrapper,
    contentWrapperProps: props.contentWrapperProps,
    trustedHosts: props.trustedHosts,
    children: [
      props.isSsrAbTest ? /* @__PURE__ */ jsx(InlinedScript, {
        id: "builderio-variant-visibility",
        scriptStr: state.scriptStr,
        nonce: props.nonce || ""
      }) : null,
      /* @__PURE__ */ jsx(ContentStyles, {
        nonce: props.nonce || "",
        isNestedRender: props.isNestedRender,
        contentId: (_e = state.builderContextSignal.content) == null ? void 0 : _e.id,
        cssCode: (_g = (_f = state.builderContextSignal.content) == null ? void 0 : _f.data) == null ? void 0 : _g.cssCode,
        customFonts: (_i = (_h = state.builderContextSignal.content) == null ? void 0 : _h.data) == null ? void 0 : _i.customFonts
      }),
      /* @__PURE__ */ jsx(Blocks, {
        blocks: (_k = (_j = state.builderContextSignal.content) == null ? void 0 : _j.data) == null ? void 0 : _k.blocks,
        context: state.builderContextSignal,
        registeredComponents: state.registeredComponents,
        linkComponent: props.linkComponent
      })
    ]
  });
});
export {
  ContentComponent,
  ContentComponent as default
};
